@@ -1,6 +1,6 @@
 package Treex;
-BEGIN {
-  $Treex::VERSION = '0.08399';
+{
+  $Treex::VERSION = '0.08663';
 }
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ Treex - Natural Language Processing framework
 
 =head1 VERSION
 
-version 0.08399
+version 0.08663
 
 =head1 INTRODUCTION
 
@@ -138,6 +138,8 @@ distributions are hoped to appear soon too.
 
 =head1 REFERENCES
 
+L<Treex website|http://ufal.mff.cuni.cz/treex>
+
 Selected TectoMT/Treex-related publications:
 
 - Žabokrtský Zdeněk, Ptáček Jan, Pajas Petr:
@@ -198,4 +200,4 @@ Daniel Zeman
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
