@@ -1,8 +1,10 @@
 package Treex::Core::Bundle;
-BEGIN {
-  $Treex::Core::Bundle::VERSION = '0.08399';
+{
+  $Treex::Core::Bundle::VERSION = '0.08663';
 }
 
+use namespace::autoclean;
+
 use Moose;
 use Treex::Core::Common;
 use MooseX::NonMoose;
@@ -267,6 +269,11 @@ sub get_attr {
     return $self->{$attr_name};
 }
 
+# ------- other -------------
+
+sub following {
+    Treex::Core::Node::following(@_);
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -285,7 +292,7 @@ Treex::Core::Bundle - a set of equivalent sentences in the Treex framework
 
 =head1 VERSION
 
-version 0.08399
+version 0.08663
 
 =head1 DESCRIPTION
 
@@ -404,4 +411,4 @@ Zdeněk Žabokrtský <zabokrtsky@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
