@@ -1,7 +1,10 @@
 package Treex::Core::Node::P;
-BEGIN {
-  $Treex::Core::Node::P::VERSION = '0.08399';
+{
+  $Treex::Core::Node::P::VERSION = '0.08663';
 }
+
+use namespace::autoclean;
+
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Core::Node';
@@ -224,7 +227,7 @@ Treex::Core::Node::P
 
 =head1 VERSION
 
-version 0.08399
+version 0.08663
 
 =head1 DESCRIPTION
 
@@ -281,4 +284,4 @@ Daniel Zeman <zeman@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
