@@ -1,7 +1,10 @@
 package Treex::Core::Node::T;
-BEGIN {
-  $Treex::Core::Node::T::VERSION = '0.08399';
+{
+  $Treex::Core::Node::T::VERSION = '0.08663';
 }
+
+use namespace::autoclean;
+
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Core::Node';
@@ -327,7 +330,7 @@ Treex::Core::Node::T
 
 =head1 VERSION
 
-version 0.08399
+version 0.08663
 
 =head1 DESCRIPTION
 
@@ -460,4 +463,4 @@ Ondřej Dušek <odusek@ufal.mff.cuni.cz>
 
 Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
