@@ -1,13 +1,13 @@
 package Treex::Core::Scenario;
-BEGIN {
-  $Treex::Core::Scenario::VERSION = '0.08399';
+{
+  $Treex::Core::Scenario::VERSION = '0.08663';
 }
 use Moose;
 use Treex::Core::Common;
 use File::Basename;
 use File::Slurp;
 use File::chdir;
-use Parse::RecDescent 1.967003;
+#use Parse::RecDescent 1.967003; now using standalone version
 
 has from_file => (
     is            => 'ro',
@@ -76,7 +76,7 @@ has _global_params => (
 
 has parser => (
     is            => 'ro',
-    isa           => 'Parse::RecDescent',
+    isa           => 'Parse::RecDescent::_Runtime',
     init_arg      => undef,
     builder       => '_build_parser',
     documentation => q{Parses treex scenarios}
@@ -153,15 +153,21 @@ sub _build_parser {
     my $dir  = $self->_my_dir();             #get module's directory
     my $file = "$dir/ScenarioParser.rdg";    #find grammar file
     log_fatal("Cannot find grammar file") if !-e $file;
+
+    #in fact we should never reach this
+    log_warn('We should NOT reach this place. Treex distribution may be corrupted.');
+
     my $grammar = read_file($file);          #load it
     eval {
         log_info("Trying to precompile it for you");
+        require Parse::RecDescent;
         local $CWD = $dir;
-        Parse::RecDescent->Precompile( $grammar, 'Treex::Core::ScenarioParser' );
+        Parse::RecDescent->Precompile( {-standalone => 1 }, $grammar, 'Treex::Core::ScenarioParser' );
         $parser = $self->_load_parser();
         1;
     } or eval {
         log_info("Cannot precompile, loading directly from grammar. Consider precompiling it manually");
+        require Parse::RecDescent;
         $parser = Parse::RecDescent->new($grammar);    #create parser
         1;
     } or log_fatal("Cannot create Scenario parser");
@@ -210,6 +216,22 @@ sub construct_scenario_string {
     return join $delim, @block_strings;
 }
 
+
+# reverse of parse_scenario_string, used in Treex::Core::Run for treex --dump
+sub get_required_files {
+    my $self        = shift;
+    my @block_items = @{ $self->block_items };
+    my @required_files;
+    foreach my $block_item (@block_items) {
+        my $block = $self->_load_block($block_item);
+        push @required_files,
+            map {
+                $block_item->{block_name} . "\t" . $_;
+            } $block->get_required_share_files();
+    }
+    return @required_files;
+}
+
 sub _add_quotes {    # adding quotes only if param. value contains a space
     my ($block_parameter) = @_;
     my ( $name, $value ) = split /=/, $block_parameter, 2;
@@ -262,6 +284,11 @@ sub run {
     my $number_of_documents = $reader->number_of_documents_per_this_job() || '?';
     my $document_number     = 0;
 
+    log_info "Applying process_start";
+    foreach my $block ( @{ $self->loaded_blocks } ) {
+        $block->process_start();
+    }
+
     while ( my $document = $reader->next_document_for_this_job() ) {
         $document_number++;
         my $doc_name = $document->full_filename;
@@ -320,7 +347,7 @@ Treex::Core::Scenario - a larger Treex processing unit, composed of blocks
 
 =head1 VERSION
 
-version 0.08399
+version 0.08663
 
 =head1 SYNOPSIS
 
@@ -454,4 +481,4 @@ Tomáš Kraut <kraut@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
